@@ -38,7 +38,6 @@ L2tpAuthDialog::L2tpAuthDialog(const NetworkManager::VpnSetting::Ptr &setting, Q
     Q_D(L2tpAuthDialog);
     d->ui.setupUi(this);
     d->setting = setting;
-    connect(d->ui.cbShowPasswords, &QCheckBox::toggled, this, &L2tpAuthDialog::showPasswordsChanged);
 
     KAcceleratorManager::manage(this);
 
@@ -76,10 +75,9 @@ void L2tpAuthDialog::readSecrets()
     }
 }
 
-QVariantMap L2tpAuthDialog::setting(bool agentOwned) const
+QVariantMap L2tpAuthDialog::setting() const
 {
     Q_D(const L2tpAuthDialog);
-    Q_UNUSED(agentOwned)
 
     NMStringMap secrets;
     QVariantMap result;
@@ -92,13 +90,3 @@ QVariantMap L2tpAuthDialog::setting(bool agentOwned) const
 
     return result;
 }
-
-void L2tpAuthDialog::showPasswordsChanged(bool show)
-{
-    Q_D(L2tpAuthDialog);
-    if (show) {
-        d->ui.leUserPassword->setEchoMode(QLineEdit::Normal);
-    } else {
-        d->ui.leUserPassword->setEchoMode(QLineEdit::Password);
-    }
-}
